@@ -442,6 +442,7 @@ def create_big_index(
     max_index_memory_usage: str,
     min_nearest_neighbors_to_retrieve: int,
     embedding_column_name: str,
+    index_key: str,
     current_memory_available: str,
     nb_cores: Optional[int],
     use_gpu: bool,
@@ -458,6 +459,7 @@ def create_big_index(
         trained_index = create_and_train_index_from_embedding_dir(
             embedding_root_dir=embedding_root_dir,
             embedding_column_name=embedding_column_name,
+            index_key=index_key,
             max_index_memory_usage=max_index_memory_usage,
             make_direct_map=make_direct_map,
             should_be_memory_mappable=should_be_memory_mappable,
@@ -518,6 +520,7 @@ def create_small_index(
     max_index_memory_usage: str = "16G",
     min_nearest_neighbors_to_retrieve: int = 20,
     embedding_column_name: str = "embedding",
+    index_key: Optional[str] = None,
     current_memory_available: str = "32G",
     use_gpu: bool = False,
     metric_type: str = "ip",
@@ -532,6 +535,7 @@ def create_small_index(
     trained_index = create_and_train_index_from_embedding_dir(
         embedding_root_dir=embedding_root_dir,
         embedding_column_name=embedding_column_name,
+        index_key=index_key,
         max_index_memory_usage=max_index_memory_usage,
         make_direct_map=make_direct_map,
         should_be_memory_mappable=should_be_memory_mappable,
@@ -571,6 +575,7 @@ def create_partitioned_indexes(
     max_index_query_time_ms: float = 10.0,
     min_nearest_neighbors_to_retrieve: int = 20,
     embedding_column_name: str = "embedding",
+    index_key: Optional[str] = None,
     max_index_memory_usage: str = "16G",
     current_memory_available: str = "32G",
     use_gpu: bool = False,
@@ -597,6 +602,7 @@ def create_partitioned_indexes(
                 max_index_memory_usage=max_index_memory_usage,
                 min_nearest_neighbors_to_retrieve=min_nearest_neighbors_to_retrieve,
                 embedding_column_name=embedding_column_name,
+                index_key=index_key,
                 current_memory_available=current_memory_available,
                 use_gpu=use_gpu,
                 metric_type=metric_type,
@@ -617,6 +623,7 @@ def create_partitioned_indexes(
         max_index_memory_usage=max_index_memory_usage,
         min_nearest_neighbors_to_retrieve=min_nearest_neighbors_to_retrieve,
         embedding_column_name=embedding_column_name,
+        index_key=index_key,
         current_memory_available=current_memory_available,
         nb_cores=nb_cores,
         use_gpu=use_gpu,
